# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kedro_grpc_server/kedro.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='kedro_grpc_server/kedro.proto',
  package='kedro',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dkedro_grpc_server/kedro.proto\x12\x05kedro\"-\n\nRunSummary\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\t\"0\n\tRunParams\x12\x15\n\rpipeline_name\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x01(\t\"#\n\x0fPipelineSummary\x12\x10\n\x08pipeline\x18\x01 \x03(\t\"\x10\n\x0ePipelineParams\"\x17\n\x05RunId\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"c\n\tRunStatus\x12\x0e\n\x06\x65vents\x18\x01 \x03(\t\x12\x11\n\texit_code\x18\x02 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x0f\n\x07success\x18\x04 \x01(\t\x12\x12\n\nrun_status\x18\x05 \x01(\t2\xa1\x01\n\x05Kedro\x12>\n\rListPipelines\x12\x15.kedro.PipelineParams\x1a\x16.kedro.PipelineSummary\x12*\n\x03Run\x12\x10.kedro.RunParams\x1a\x11.kedro.RunSummary\x12,\n\x06Status\x12\x0c.kedro.RunId\x1a\x10.kedro.RunStatus\"\x00\x30\x01\x62\x06proto3'
)




_RUNSUMMARY = _descriptor.Descriptor(
  name='RunSummary',
  full_name='kedro.RunSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='kedro.RunSummary.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='kedro.RunSummary.success', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=85,
)


_RUNPARAMS = _descriptor.Descriptor(
  name='RunParams',
  full_name='kedro.RunParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline_name', full_name='kedro.RunParams.pipeline_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='kedro.RunParams.tags', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=135,
)


_PIPELINESUMMARY = _descriptor.Descriptor(
  name='PipelineSummary',
  full_name='kedro.PipelineSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='kedro.PipelineSummary.pipeline', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=172,
)


_PIPELINEPARAMS = _descriptor.Descriptor(
  name='PipelineParams',
  full_name='kedro.PipelineParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=190,
)


_RUNID = _descriptor.Descriptor(
  name='RunId',
  full_name='kedro.RunId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='kedro.RunId.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=215,
)


_RUNSTATUS = _descriptor.Descriptor(
  name='RunStatus',
  full_name='kedro.RunStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='kedro.RunStatus.events', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='kedro.RunStatus.exit_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='kedro.RunStatus.run_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='kedro.RunStatus.success', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run_status', full_name='kedro.RunStatus.run_status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=316,
)

DESCRIPTOR.message_types_by_name['RunSummary'] = _RUNSUMMARY
DESCRIPTOR.message_types_by_name['RunParams'] = _RUNPARAMS
DESCRIPTOR.message_types_by_name['PipelineSummary'] = _PIPELINESUMMARY
DESCRIPTOR.message_types_by_name['PipelineParams'] = _PIPELINEPARAMS
DESCRIPTOR.message_types_by_name['RunId'] = _RUNID
DESCRIPTOR.message_types_by_name['RunStatus'] = _RUNSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunSummary = _reflection.GeneratedProtocolMessageType('RunSummary', (_message.Message,), {
  'DESCRIPTOR' : _RUNSUMMARY,
  '__module__' : 'kedro_grpc_server.kedro_pb2'
  # @@protoc_insertion_point(class_scope:kedro.RunSummary)
  })
_sym_db.RegisterMessage(RunSummary)

RunParams = _reflection.GeneratedProtocolMessageType('RunParams', (_message.Message,), {
  'DESCRIPTOR' : _RUNPARAMS,
  '__module__' : 'kedro_grpc_server.kedro_pb2'
  # @@protoc_insertion_point(class_scope:kedro.RunParams)
  })
_sym_db.RegisterMessage(RunParams)

PipelineSummary = _reflection.GeneratedProtocolMessageType('PipelineSummary', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINESUMMARY,
  '__module__' : 'kedro_grpc_server.kedro_pb2'
  # @@protoc_insertion_point(class_scope:kedro.PipelineSummary)
  })
_sym_db.RegisterMessage(PipelineSummary)

PipelineParams = _reflection.GeneratedProtocolMessageType('PipelineParams', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINEPARAMS,
  '__module__' : 'kedro_grpc_server.kedro_pb2'
  # @@protoc_insertion_point(class_scope:kedro.PipelineParams)
  })
_sym_db.RegisterMessage(PipelineParams)

RunId = _reflection.GeneratedProtocolMessageType('RunId', (_message.Message,), {
  'DESCRIPTOR' : _RUNID,
  '__module__' : 'kedro_grpc_server.kedro_pb2'
  # @@protoc_insertion_point(class_scope:kedro.RunId)
  })
_sym_db.RegisterMessage(RunId)

RunStatus = _reflection.GeneratedProtocolMessageType('RunStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNSTATUS,
  '__module__' : 'kedro_grpc_server.kedro_pb2'
  # @@protoc_insertion_point(class_scope:kedro.RunStatus)
  })
_sym_db.RegisterMessage(RunStatus)



_KEDRO = _descriptor.ServiceDescriptor(
  name='Kedro',
  full_name='kedro.Kedro',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=319,
  serialized_end=480,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPipelines',
    full_name='kedro.Kedro.ListPipelines',
    index=0,
    containing_service=None,
    input_type=_PIPELINEPARAMS,
    output_type=_PIPELINESUMMARY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Run',
    full_name='kedro.Kedro.Run',
    index=1,
    containing_service=None,
    input_type=_RUNPARAMS,
    output_type=_RUNSUMMARY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Status',
    full_name='kedro.Kedro.Status',
    index=2,
    containing_service=None,
    input_type=_RUNID,
    output_type=_RUNSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KEDRO)

DESCRIPTOR.services_by_name['Kedro'] = _KEDRO

# @@protoc_insertion_point(module_scope)
